library(tidyverse)

# Read data into R.
quant <- read_csv(file = "blot_quantifications_26042018.csv")

# Summarise the data for plotting.
summary <- quant %>% select(Sample, Antibody, Norm.H3, Norm.Actin) %>% 
           group_by(Antibody, Sample) %>% 
           summarise(H3 = mean(Norm.H3),
                    Actin = mean(Norm.Actin),
                    sd.H3 = sd(Norm.H3),
                    sd.Actin = sd(Norm.Actin)) 

print(summary)

# Plot results as a bar graph.

summary %>% 
  gather(Normalizer, FoldChange, 3:4) %>% 
  mutate(StdDev = case_when(Normalizer == "Actin" ~ sd.Actin, 
                            Normalizer == "H3" ~ sd.H3)) %>%
  mutate(Normalizer = str_replace(Normalizer, "mean.Actin", "Normalized to Actin")) %>% 
  mutate(Normalizer = str_replace(Normalizer, "mean.H3", "Normalized to H3")) %>% 
  select(Antibody, Sample, FoldChange, Normalizer, StdDev) %>% 
  ggplot(aes(Sample, FoldChange, fill = Antibody)) +
  geom_bar(stat = "identity", colour = "black", 
           position  = position_dodge()) +
  geom_errorbar(aes(ymax = FoldChange + StdDev, 
                    ymin = FoldChange - StdDev),
                position = position_dodge()) +
  facet_grid(. ~ Normalizer) +
  theme_classic() +
  ylab("Fold Change \n Relative to siCNTRL") +
  xlab("") +
  scale_fill_brewer(palette = "Set2")


# T-test for significance.

siCNTRL <- quant %>%
  filter(Antibody == "E-Cadherin" 
         & Sample == "siCNTRL") %>% 
  select(Norm.H3, Norm.Actin)

siNSD3 <- quant %>%
          filter(Antibody == "E-Cadherin" 
                 & Sample == "siNSD3") %>% 
          select(Norm.H3, Norm.Actin)

t.test(siCNTRL$Norm.H3, siNSD3$Norm.H3)


t.test(siCNTRL$Norm.Actin, siNSD3$Norm.Actin)


                    
              

